==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/fields/UnreachableFieldsTagger.h <==
// public class soot.jimple.toolkits.annotation.fields.UnreachableFieldsTagger

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 395ea04ae4a06abe soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger_H_
#define _JC_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_refs	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$refs	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$nonrefs	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vmethods	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtable	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtype	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object *_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$method$v$dbde5436028c8e59(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vmethods {
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vmethods	soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$refs {
    _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_refs	soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_nonrefs	soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object {
	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtype _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/fields/UnreachableFieldsTagger.h <==
// public class soot.jimple.toolkits.annotation.fields.UnreachableFieldsTagger

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 395ea04ae4a06abe soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger_H_
#define _JC_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_refs	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$refs	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$nonrefs	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vmethods	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtable	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtype	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object *_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$method$v$dbde5436028c8e59(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vmethods {
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vmethods	soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$refs {
    _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_refs	soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$sub_nonrefs	soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$object {
	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$vtype _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_fields_UnreachableFieldsTagger_H_ */
